@@ -1,12 +1,12 @@
 =begin
   locale.rb - Locale module
 
-  Copyright (C) 2002,2003  Masao Mutoh <mutoh@highway.ne.jp>
+  Copyright (C) 2002-2005  Masao Mutoh
 
   You may redistribute it and/or modify it under the same
   license terms as Ruby.
 
-  $Id: locale.rb,v 1.5 2004/02/14 12:59:11 mutoh Exp $
+  $Id: locale.rb,v 1.6 2005/03/28 13:25:48 mutoh Exp $
 =end
 
 if /cygwin|mingw|mswin32|bccwin32/ =~ RUBY_PLATFORM
@@ -19,7 +19,7 @@ module Locale
   def get
     lc = __get
     ret = nil
-    ["LC_ALL", "LC_CTYPE", "LC_MESSAGES", "LANG"].each do |env|
+    ["LC_ALL", "LC_MESSAGES", "LANG"].each do |env|
       ret = ENV[env]
       break if ret
     end
