@@ -82,6 +82,8 @@ class RubyLexX < RubyLex
       elsif (ch = getc) == "\\" #"
         read_escape
       end
+    when '#'
+      return ch
     else
       # other characters
     end
