@@ -20,7 +20,7 @@ class TestLib4
   def test_3_2
     n_("eee\neee\n" ,
        "eee2\neee2\n" , 
-       ,1)
+       1)
   end
 
   def test_4
@@ -57,7 +57,7 @@ eee2", 1)
 
   def test_9
     n_("mmm" + "mmm","mmm2" + "mmm2",1) + 
-    n_("nnn" ,"nnn2" ,1))
+    n_("nnn" ,"nnn2" ,1)
   end
 
 end
